# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class MeSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    client_id = marshmallow.fields.String()

    credentials_id = marshmallow.fields.String()

    provider = fields.Nested('ProviderInfo')('ProviderInfoSchema', )

    provider_id = marshmallow.fields.String()

    @validates("client_id")
    def validates_client_id(self, client_id):
        pass

    @validates("credentials_id")
    def validates_credentials_id(self, credentials_id):
        pass

    @validates("provider")
    def validates_provider(self, provider):
        pass

    @validates("provider_id")
    def validates_provider_id(self, provider_id):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return Me(local_vars_configuration=config, **data)


class Me(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_id': 'str',
        'credentials_id': 'str',
        'provider': 'ProviderInfo',
        'provider_id': 'str'
    }

    attribute_map = {
        'client_id': 'client_id',
        'credentials_id': 'credentials_id',
        'provider': 'provider',
        'provider_id': 'provider_id'
    }

    def __init__(self, client_id=missing, credentials_id=missing, provider=missing, provider_id=missing, local_vars_configuration=None):  # noqa: E501
        """Me - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = MeSchema().load({
                'client_id': client_id,
                'credentials_id': credentials_id,
                'provider': provider,
                'provider_id': provider_id
            })
            self.client_id = validated.client_id
            self.credentials_id = validated.credentials_id
            self.provider = validated.provider
            self.provider_id = validated.provider_id
        else:
            self.client_id = client_id
            self.credentials_id = credentials_id
            self.provider = provider
            self.provider_id = provider_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        return MeSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Me):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Me):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class AddressInfoSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    address = marshmallow.fields.String()

    city = marshmallow.fields.String()

    country = marshmallow.fields.String()

    state = marshmallow.fields.String()

    zip = marshmallow.fields.String()

    @validates("address")
    def validates_address(self, address):
        pass

    @validates("city")
    def validates_city(self, city):
        pass

    @validates("country")
    def validates_country(self, country):
        pass

    @validates("state")
    def validates_state(self, state):
        pass

    @validates("zip")
    def validates_zip(self, zip):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return AddressInfo(local_vars_configuration=config, **data)


class AddressInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'address': 'str',
        'city': 'str',
        'country': 'str',
        'state': 'str',
        'zip': 'str'
    }

    attribute_map = {
        'address': 'address',
        'city': 'city',
        'country': 'country',
        'state': 'state',
        'zip': 'zip'
    }

    def __init__(self, address=missing, city=missing, country=missing, state=missing, zip=missing, local_vars_configuration=None):  # noqa: E501
        """AddressInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = AddressInfoSchema().load({
                'address': address,
                'city': city,
                'country': country,
                'state': state,
                'zip': zip
            })
            self.address = validated.address
            self.city = validated.city
            self.country = validated.country
            self.state = validated.state
            self.zip = validated.zip
        else:
            self.address = address
            self.city = city
            self.country = country
            self.state = state
            self.zip = zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        return AddressInfoSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddressInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddressInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class TransactionSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    amount = marshmallow.fields.Float()

    balance = fields.Nested('Balance')('BalanceSchema', )

    currency = marshmallow.fields.String()

    description = marshmallow.fields.String()

    meta = marshmallow.fields.Dict(keys=marshmallow.fields.String(), values=marshmallow.fields.String()
,)

    timestamp = fields.DateTime()

    transaction_id = marshmallow.fields.String()

    transaction_type = marshmallow.fields.String()

    @validates("amount")
    def validates_amount(self, amount):
        pass

    @validates("balance")
    def validates_balance(self, balance):
        pass

    @validates("currency")
    def validates_currency(self, currency):
        pass

    @validates("description")
    def validates_description(self, description):
        pass

    @validates("meta")
    def validates_meta(self, meta):
        pass

    @validates("timestamp")
    def validates_timestamp(self, timestamp):
        pass

    @validates("transaction_id")
    def validates_transaction_id(self, transaction_id):
        pass

    @validates("transaction_type")
    def validates_transaction_type(self, transaction_type):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return Transaction(local_vars_configuration=config, **data)


class Transaction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'amount': 'float',
        'balance': 'Balance',
        'currency': 'str',
        'description': 'str',
        'meta': 'dict(str, str)',
        'timestamp': 'datetime',
        'transaction_id': 'str',
        'transaction_type': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'balance': 'balance',
        'currency': 'currency',
        'description': 'description',
        'meta': 'meta',
        'timestamp': 'timestamp',
        'transaction_id': 'transaction_id',
        'transaction_type': 'transaction_type'
    }

    def __init__(self, amount=missing, balance=missing, currency=missing, description=missing, meta=missing, timestamp=missing, transaction_id=missing, transaction_type=missing, local_vars_configuration=None):  # noqa: E501
        """Transaction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = TransactionSchema().load({
                'amount': amount,
                'balance': balance,
                'currency': currency,
                'description': description,
                'meta': meta,
                'timestamp': timestamp,
                'transaction_id': transaction_id,
                'transaction_type': transaction_type
            })
            self.amount = validated.amount
            self.balance = validated.balance
            self.currency = validated.currency
            self.description = validated.description
            self.meta = validated.meta
            self.timestamp = validated.timestamp
            self.transaction_id = validated.transaction_id
            self.transaction_type = validated.transaction_type
        else:
            self.amount = amount
            self.balance = balance
            self.currency = currency
            self.description = description
            self.meta = meta
            self.timestamp = timestamp
            self.transaction_id = transaction_id
            self.transaction_type = transaction_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        return TransactionSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transaction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Transaction):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class CardBalanceSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    available = marshmallow.fields.Float()

    credit_limit = marshmallow.fields.Float()

    currency = marshmallow.fields.String()

    current = marshmallow.fields.Float()

    last_statement_balance = marshmallow.fields.Float()

    last_statement_date = fields.DateTime()

    payment_due = marshmallow.fields.Float()

    payment_due_date = fields.DateTime()

    update_timestamp = fields.DateTime()

    @validates("available")
    def validates_available(self, available):
        pass

    @validates("credit_limit")
    def validates_credit_limit(self, credit_limit):
        pass

    @validates("currency")
    def validates_currency(self, currency):
        pass

    @validates("current")
    def validates_current(self, current):
        pass

    @validates("last_statement_balance")
    def validates_last_statement_balance(self, last_statement_balance):
        pass

    @validates("last_statement_date")
    def validates_last_statement_date(self, last_statement_date):
        pass

    @validates("payment_due")
    def validates_payment_due(self, payment_due):
        pass

    @validates("payment_due_date")
    def validates_payment_due_date(self, payment_due_date):
        pass

    @validates("update_timestamp")
    def validates_update_timestamp(self, update_timestamp):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return CardBalance(local_vars_configuration=config, **data)


class CardBalance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'available': 'float',
        'credit_limit': 'float',
        'currency': 'str',
        'current': 'float',
        'last_statement_balance': 'float',
        'last_statement_date': 'datetime',
        'payment_due': 'float',
        'payment_due_date': 'datetime',
        'update_timestamp': 'datetime'
    }

    attribute_map = {
        'available': 'available',
        'credit_limit': 'credit_limit',
        'currency': 'currency',
        'current': 'current',
        'last_statement_balance': 'last_statement_balance',
        'last_statement_date': 'last_statement_date',
        'payment_due': 'payment_due',
        'payment_due_date': 'payment_due_date',
        'update_timestamp': 'update_timestamp'
    }

    def __init__(self, available=missing, credit_limit=missing, currency=missing, current=missing, last_statement_balance=missing, last_statement_date=missing, payment_due=missing, payment_due_date=missing, update_timestamp=missing, local_vars_configuration=None):  # noqa: E501
        """CardBalance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = CardBalanceSchema().load({
                'available': available,
                'credit_limit': credit_limit,
                'currency': currency,
                'current': current,
                'last_statement_balance': last_statement_balance,
                'last_statement_date': last_statement_date,
                'payment_due': payment_due,
                'payment_due_date': payment_due_date,
                'update_timestamp': update_timestamp
            })
            self.available = validated.available
            self.credit_limit = validated.credit_limit
            self.currency = validated.currency
            self.current = validated.current
            self.last_statement_balance = validated.last_statement_balance
            self.last_statement_date = validated.last_statement_date
            self.payment_due = validated.payment_due
            self.payment_due_date = validated.payment_due_date
            self.update_timestamp = validated.update_timestamp
        else:
            self.available = available
            self.credit_limit = credit_limit
            self.currency = currency
            self.current = current
            self.last_statement_balance = last_statement_balance
            self.last_statement_date = last_statement_date
            self.payment_due = payment_due
            self.payment_due_date = payment_due_date
            self.update_timestamp = update_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        return CardBalanceSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CardBalance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CardBalance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class APIResponseCardSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    results = marshmallow.fields.List(fields.Nested('Card')('CardSchema', )
,)

    results_uri = marshmallow.fields.String()

    status = marshmallow.fields.String()

    task_id = marshmallow.fields.String()

    @validates("results")
    def validates_results(self, results):
        pass

    @validates("results_uri")
    def validates_results_uri(self, results_uri):
        pass

    @validates("status")
    def validates_status(self, status):
        allowed_values = ["Queued", "Running", "Succeeded", "Failed"]  # noqa: E501
        if status not in allowed_values:  # noqa: E501
            raise ValidationError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )
        pass

    @validates("task_id")
    def validates_task_id(self, task_id):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return APIResponseCard(local_vars_configuration=config, **data)


class APIResponseCard(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'results': 'list[Card]',
        'results_uri': 'str',
        'status': 'str',
        'task_id': 'str'
    }

    attribute_map = {
        'results': 'results',
        'results_uri': 'results_uri',
        'status': 'status',
        'task_id': 'task_id'
    }

    def __init__(self, results=missing, results_uri=missing, status=missing, task_id=missing, local_vars_configuration=None):  # noqa: E501
        """APIResponseCard - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = APIResponseCardSchema().load({
                'results': results,
                'results_uri': results_uri,
                'status': status,
                'task_id': task_id
            })
            self.results = validated.results
            self.results_uri = validated.results_uri
            self.status = validated.status
            self.task_id = validated.task_id
        else:
            self.results = results
            self.results_uri = results_uri
            self.status = status
            self.task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        return APIResponseCardSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, APIResponseCard):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, APIResponseCard):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class CardSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    account_id = marshmallow.fields.String()

    card_network = marshmallow.fields.String()

    card_type = marshmallow.fields.String()

    currency = marshmallow.fields.String()

    display_name = marshmallow.fields.String()

    name_on_card = marshmallow.fields.String()

    partial_card_number = marshmallow.fields.String()

    provider = fields.Nested('ProviderInfo')('ProviderInfoSchema', )

    update_timestamp = fields.DateTime()

    valid_from = marshmallow.fields.String()

    valid_to = marshmallow.fields.String()

    @validates("account_id")
    def validates_account_id(self, account_id):
        pass

    @validates("card_network")
    def validates_card_network(self, card_network):
        pass

    @validates("card_type")
    def validates_card_type(self, card_type):
        pass

    @validates("currency")
    def validates_currency(self, currency):
        pass

    @validates("display_name")
    def validates_display_name(self, display_name):
        pass

    @validates("name_on_card")
    def validates_name_on_card(self, name_on_card):
        pass

    @validates("partial_card_number")
    def validates_partial_card_number(self, partial_card_number):
        pass

    @validates("provider")
    def validates_provider(self, provider):
        pass

    @validates("update_timestamp")
    def validates_update_timestamp(self, update_timestamp):
        pass

    @validates("valid_from")
    def validates_valid_from(self, valid_from):
        pass

    @validates("valid_to")
    def validates_valid_to(self, valid_to):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return Card(local_vars_configuration=config, **data)


class Card(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'card_network': 'str',
        'card_type': 'str',
        'currency': 'str',
        'display_name': 'str',
        'name_on_card': 'str',
        'partial_card_number': 'str',
        'provider': 'ProviderInfo',
        'update_timestamp': 'datetime',
        'valid_from': 'str',
        'valid_to': 'str'
    }

    attribute_map = {
        'account_id': 'account_id',
        'card_network': 'card_network',
        'card_type': 'card_type',
        'currency': 'currency',
        'display_name': 'display_name',
        'name_on_card': 'name_on_card',
        'partial_card_number': 'partial_card_number',
        'provider': 'provider',
        'update_timestamp': 'update_timestamp',
        'valid_from': 'valid_from',
        'valid_to': 'valid_to'
    }

    def __init__(self, account_id=missing, card_network=missing, card_type=missing, currency=missing, display_name=missing, name_on_card=missing, partial_card_number=missing, provider=missing, update_timestamp=missing, valid_from=missing, valid_to=missing, local_vars_configuration=None):  # noqa: E501
        """Card - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = CardSchema().load({
                'account_id': account_id,
                'card_network': card_network,
                'card_type': card_type,
                'currency': currency,
                'display_name': display_name,
                'name_on_card': name_on_card,
                'partial_card_number': partial_card_number,
                'provider': provider,
                'update_timestamp': update_timestamp,
                'valid_from': valid_from,
                'valid_to': valid_to
            })
            self.account_id = validated.account_id
            self.card_network = validated.card_network
            self.card_type = validated.card_type
            self.currency = validated.currency
            self.display_name = validated.display_name
            self.name_on_card = validated.name_on_card
            self.partial_card_number = validated.partial_card_number
            self.provider = validated.provider
            self.update_timestamp = validated.update_timestamp
            self.valid_from = validated.valid_from
            self.valid_to = validated.valid_to
        else:
            self.account_id = account_id
            self.card_network = card_network
            self.card_type = card_type
            self.currency = currency
            self.display_name = display_name
            self.name_on_card = name_on_card
            self.partial_card_number = partial_card_number
            self.provider = provider
            self.update_timestamp = update_timestamp
            self.valid_from = valid_from
            self.valid_to = valid_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        return CardSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Card):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Card):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class AccountNumberSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    iban = marshmallow.fields.String()

    number = marshmallow.fields.String()

    sort_code = marshmallow.fields.String()

    swift_bic = marshmallow.fields.String()

    @validates("iban")
    def validates_iban(self, iban):
        pass

    @validates("number")
    def validates_number(self, number):
        pass

    @validates("sort_code")
    def validates_sort_code(self, sort_code):
        pass

    @validates("swift_bic")
    def validates_swift_bic(self, swift_bic):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return AccountNumber(local_vars_configuration=config, **data)


class AccountNumber(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'iban': 'str',
        'number': 'str',
        'sort_code': 'str',
        'swift_bic': 'str'
    }

    attribute_map = {
        'iban': 'iban',
        'number': 'number',
        'sort_code': 'sort_code',
        'swift_bic': 'swift_bic'
    }

    def __init__(self, iban=missing, number=missing, sort_code=missing, swift_bic=missing, local_vars_configuration=None):  # noqa: E501
        """AccountNumber - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = AccountNumberSchema().load({
                'iban': iban,
                'number': number,
                'sort_code': sort_code,
                'swift_bic': swift_bic
            })
            self.iban = validated.iban
            self.number = validated.number
            self.sort_code = validated.sort_code
            self.swift_bic = validated.swift_bic
        else:
            self.iban = iban
            self.number = number
            self.sort_code = sort_code
            self.swift_bic = swift_bic

    def to_dict(self):
        """Returns the model properties as a dict"""
        return AccountNumberSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountNumber):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountNumber):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer
from truelayer.models.account_number import AccountNumber  # noqa: E501
from truelayer.rest import ApiException

class TestAccountNumber(unittest.TestCase):
    """AccountNumber unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AccountNumber
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.models.account_number.AccountNumber()  # noqa: E501
        if include_optional :
            return AccountNumber(
                iban = '0', 
                number = '0', 
                sort_code = '0', 
                swift_bic = '0'
            )
        else :
            return AccountNumber(
        )

    def testAccountNumber(self):
        """Test AccountNumber"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer import fields
from truelayer.configuration import Configuration



class InfoSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    addresses = marshmallow.fields.List(fields.Nested('AddressInfo')('AddressInfoSchema', )
,)

    date_of_birth = fields.DateTime()

    emails = marshmallow.fields.List(marshmallow.fields.String()
,)

    full_name = marshmallow.fields.String()

    phones = marshmallow.fields.List(marshmallow.fields.String()
,)

    update_timestamp = fields.DateTime()

    @validates("addresses")
    def validates_addresses(self, addresses):
        pass

    @validates("date_of_birth")
    def validates_date_of_birth(self, date_of_birth):
        pass

    @validates("emails")
    def validates_emails(self, emails):
        pass

    @validates("full_name")
    def validates_full_name(self, full_name):
        pass

    @validates("phones")
    def validates_phones(self, phones):
        pass

    @validates("update_timestamp")
    def validates_update_timestamp(self, update_timestamp):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return Info(local_vars_configuration=config, **data)


class Info(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'addresses': 'list[AddressInfo]',
        'date_of_birth': 'datetime',
        'emails': 'list[str]',
        'full_name': 'str',
        'phones': 'list[str]',
        'update_timestamp': 'datetime'
    }

    attribute_map = {
        'addresses': 'addresses',
        'date_of_birth': 'date_of_birth',
        'emails': 'emails',
        'full_name': 'full_name',
        'phones': 'phones',
        'update_timestamp': 'update_timestamp'
    }

    def __init__(self, addresses=missing, date_of_birth=missing, emails=missing, full_name=missing, phones=missing, update_timestamp=missing, local_vars_configuration=None):  # noqa: E501
        """Info - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = InfoSchema().load({
                'addresses': addresses,
                'date_of_birth': date_of_birth,
                'emails': emails,
                'full_name': full_name,
                'phones': phones,
                'update_timestamp': update_timestamp
            })
            self.addresses = validated.addresses
            self.date_of_birth = validated.date_of_birth
            self.emails = validated.emails
            self.full_name = validated.full_name
            self.phones = validated.phones
            self.update_timestamp = validated.update_timestamp
        else:
            self.addresses = addresses
            self.date_of_birth = date_of_birth
            self.emails = emails
            self.full_name = full_name
            self.phones = phones
            self.update_timestamp = update_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        return InfoSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Info):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Info):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Authtentication

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer.auth import fields
from truelayer.auth.configuration import Configuration



class ProviderSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    country = marshmallow.fields.String()

    display_name = marshmallow.fields.String()

    logo_url = marshmallow.fields.String()

    provider_id = marshmallow.fields.String()

    scopes = marshmallow.fields.List(marshmallow.fields.String()
,)

    @validates("country")
    def validates_country(self, country):
        pass

    @validates("display_name")
    def validates_display_name(self, display_name):
        pass

    @validates("logo_url")
    def validates_logo_url(self, logo_url):
        pass

    @validates("provider_id")
    def validates_provider_id(self, provider_id):
        pass

    @validates("scopes")
    def validates_scopes(self, scopes):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return Provider(local_vars_configuration=config, **data)


class Provider(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'country': 'str',
        'display_name': 'str',
        'logo_url': 'str',
        'provider_id': 'str',
        'scopes': 'list[str]'
    }

    attribute_map = {
        'country': 'country',
        'display_name': 'display_name',
        'logo_url': 'logo_url',
        'provider_id': 'provider_id',
        'scopes': 'scopes'
    }

    def __init__(self, country=missing, display_name=missing, logo_url=missing, provider_id=missing, scopes=missing, local_vars_configuration=None):  # noqa: E501
        """Provider - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = ProviderSchema().load({
                'country': country,
                'display_name': display_name,
                'logo_url': logo_url,
                'provider_id': provider_id,
                'scopes': scopes
            })
            self.country = validated.country
            self.display_name = validated.display_name
            self.logo_url = validated.logo_url
            self.provider_id = validated.provider_id
            self.scopes = validated.scopes
        else:
            self.country = country
            self.display_name = display_name
            self.logo_url = logo_url
            self.provider_id = provider_id
            self.scopes = scopes

    def to_dict(self):
        """Returns the model properties as a dict"""
        return ProviderSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Provider):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Provider):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Authtentication

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer.auth
from truelayer.auth.models.provider import Provider  # noqa: E501
from truelayer.auth.rest import ApiException

class TestProvider(unittest.TestCase):
    """Provider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Provider
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.auth.models.provider.Provider()  # noqa: E501
        if include_optional :
            return Provider(
                country = '0', 
                display_name = '0', 
                logo_url = '0', 
                provider_id = '0', 
                scopes = [
                    '0'
                    ]
            )
        else :
            return Provider(
        )

    def testProvider(self):
        """Test Provider"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    TrueLayer Authtentication

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

from truelayer.auth import fields
from truelayer.auth.configuration import Configuration



class TokenResponseSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    access_token = marshmallow.fields.String(required=True)

    expires_in = marshmallow.fields.Integer(required=True)

    token_type = marshmallow.fields.String(required=True)

    refresh_token = marshmallow.fields.String()

    expires_at = fields.DateTime()

    @validates("access_token")
    def validates_access_token(self, access_token):
        if access_token is None:  # noqa: E501
            raise ValidationError("Invalid value for `access_token`, must not be `None`")  # noqa: E501
        pass

    @validates("expires_in")
    def validates_expires_in(self, expires_in):
        if expires_in is None:  # noqa: E501
            raise ValidationError("Invalid value for `expires_in`, must not be `None`")  # noqa: E501
        pass

    @validates("token_type")
    def validates_token_type(self, token_type):
        if token_type is None:  # noqa: E501
            raise ValidationError("Invalid value for `token_type`, must not be `None`")  # noqa: E501
        pass

    @validates("refresh_token")
    def validates_refresh_token(self, refresh_token):
        pass

    @validates("expires_at")
    def validates_expires_at(self, expires_at):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return TokenResponse(local_vars_configuration=config, **data)


class TokenResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token': 'str',
        'expires_in': 'int',
        'token_type': 'str',
        'refresh_token': 'str',
        'expires_at': 'datetime'
    }

    attribute_map = {
        'access_token': 'access_token',
        'expires_in': 'expires_in',
        'token_type': 'token_type',
        'refresh_token': 'refresh_token',
        'expires_at': 'expires_at'
    }

    def __init__(self, access_token=missing, expires_in=missing, token_type='Bearer', refresh_token=missing, expires_at=missing, local_vars_configuration=None):  # noqa: E501
        """TokenResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = TokenResponseSchema().load({
                'access_token': access_token,
                'expires_in': expires_in,
                'token_type': token_type,
                'refresh_token': refresh_token,
                'expires_at': expires_at
            })
            self.access_token = validated.access_token
            self.expires_in = validated.expires_in
            self.token_type = validated.token_type
            self.refresh_token = validated.refresh_token
            self.expires_at = validated.expires_at
        else:
            self.access_token = access_token
            self.expires_in = expires_in
            self.token_type = token_type
            self.refresh_token = refresh_token
            self.expires_at = expires_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        return TokenResponseSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TokenResponse):
            return True

        return self.to_dict() != other.to_dict()
